@@ -20,7 +20,7 @@
 #ifndef ICOMPLETIONSETTINGS_H
 #define ICOMPLETIONSETTINGS_H
 
-#include <QObject>
+#include <QtCore/QObject>
 #include "interfacesexport.h"
 
 namespace KDevelop {
@@ -38,6 +38,12 @@ namespace KDevelop {
             
             Q_SCRIPTABLE virtual bool automaticCompletionEnabled() const = 0;
             
+            Q_SCRIPTABLE virtual bool semanticHighlightingEnabled() const = 0;
+            
+            Q_SCRIPTABLE virtual int localVariableColorizationLevel() const = 0;
+            
+            Q_SCRIPTABLE virtual bool highlightSemanticProblems() const = 0;
+            
         Q_SIGNALS:
             void settingsChanged(ICompletionSettings*);
     };
