@@ -20,16 +20,16 @@
 #include "duchain.h"
 #include "duchainlock.h"
 
-#include <QCoreApplication>
-#include <QHash>
-#include <QMultiMap>
-#include <QTimer>
-#include <QReadWriteLock>
-#include <qatomic.h>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QHash>
+#include <QtCore/QMultiMap>
+#include <QtCore/QTimer>
+#include <QtCore/QReadWriteLock>
+#include <QtCore/qatomic.h>
 
 #include <kglobal.h>
 
-#include <KTextEditor/Document>
+#include <KDE/KTextEditor/Document>
 
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/icore.h>
@@ -52,14 +52,13 @@
 #include "uses.h"
 #include "abstractfunctiondeclaration.h"
 #include "smartconverter.h"
-#include "duchainutils.h"
 #include "duchainregister.h"
 #include "persistentsymboltable.h"
 #include "repositories/itemrepository.h"
 #include <util/google/dense_hash_map>
-#include <qthread.h>
-#include <qwaitcondition.h>
-#include <qmutex.h>
+#include <QtCore/qthread.h>
+#include <QtCore/qwaitcondition.h>
+#include <QtCore/qmutex.h>
 #include <unistd.h>
 
 Q_DECLARE_METATYPE(KDevelop::IndexedString)
@@ -148,7 +147,7 @@ class EnvironmentInformationRequest {
   uint m_index;
 };
 
-///A list of environment-informations/top-contexts mapped to a file-name
+///A list of environment-information/top-contexts mapped to a file-name
 class EnvironmentInformationListItem {
   public:
   EnvironmentInformationListItem() {
@@ -408,7 +407,7 @@ public:
       FOREACH_FUNCTION(uint topContextIndex, item->items)
         ret << ParsingEnvironmentFilePointer(loadInformation(url, topContextIndex));
     }
-    //Add those informations that have not been added to the stored lists yet
+    //Add those information that have not been added to the stored lists yet
     ret += m_fileEnvironmentInformations.values(url);
 
     return ret;
@@ -804,7 +803,7 @@ private:
   }
 
   QMultiMap<IndexedString, ParsingEnvironmentFilePointer> m_fileEnvironmentInformations;
-  ///Maps filenames to a list of top-contexts/environment-informations. Protected by m_chainsMutex
+  ///Maps filenames to a list of top-contexts/environment-information. Protected by m_chainsMutex
   ItemRepository<EnvironmentInformationListItem, EnvironmentInformationListRequest, NoDynamicData> m_environmentListInfo;
   ///Maps top-context-indices to environment-information item. Protected by m_chainsMutex
   ItemRepository<EnvironmentInformationItem, EnvironmentInformationRequest, NoDynamicData> m_environmentInfo;
