@@ -54,7 +54,7 @@
 #include <sys/time.h>
 
 namespace std {
-#if defined(Q_OS_WIN)
+#if defined(Q_CC_MSVC)
   using namespace stdext;
 #else
   using namespace __gnu_cxx;
